/*
 * Copyright (C) 2016 Canonical Ltd.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2 or version 3 of the License.
 * See http://www.gnu.org/copyleft/lgpl.html the full text of the license.
 */

#ifndef __SNAPD_GLIB_H__
#define __SNAPD_GLIB_H__

#define __SNAPD_GLIB_INSIDE__

#include <snapd-glib/snapd-app.h>
#include <snapd-glib/snapd-auth-data.h>
#include <snapd-glib/snapd-client.h>
#include <snapd-glib/snapd-connection.h>
#include <snapd-glib/snapd-error.h>
#include <snapd-glib/snapd-icon.h>
#include <snapd-glib/snapd-login.h>
#ifdef SNAPD_BUY_SUPPORT
#include <snapd-glib/snapd-payment-method.h>
#endif
#include <snapd-glib/snapd-plug.h>
#ifdef SNAPD_BUY_SUPPORT
#include <snapd-glib/snapd-price.h>
#endif
#include <snapd-glib/snapd-slot.h>
#include <snapd-glib/snapd-snap.h>
#include <snapd-glib/snapd-system-information.h>
#include <snapd-glib/snapd-task.h>

#undef __SNAPD_GLIB_INSIDE__

#endif /* __SNAPD_GLIB_H__ */
